@@ -175,7 +175,7 @@ class Module:
             if systemIcon != "":
                 try:
                     if "/" in systemIcon:
-                        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale (systemIconPath, -1, 100, True)
+                        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(systemIcon, -1, 100, True)
                         systemIcon = Gtk.Image.new_from_pixbuf(pixbuf)
                     else:
                         systemIcon = Gtk.Image.new_from_icon_name(systemIcon, Gtk.IconSize.DIALOG)
@@ -222,31 +222,12 @@ class Module:
 
     def on_copy_clipboard_button_clicked(self, button):
         try:
-            # taken from https://github.com/linuxmint/xapp/blob/master/scripts/upload-system-info
-            subproc = Gio.Subprocess.new(['inxi', '-Fxxrzc0'], Gio.SubprocessFlags.STDOUT_PIPE |  Gio.SubprocessFlags.STDERR_PIPE)
-            subproc.wait_check_async(None, self.on_copy_clipboard_complete)
+            inxiOutput = subprocess.run(['inxi', '-Fxxrzc0'], check=True, stdout=subprocess.PIPE).stdout
+            clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
+            clipboard.set_text(inxiOutput.decode("utf-8"), -1)
         except Exception as e:
-            print ("An error occurred while copying the system information to clipboard")
-            print (e)
-
-    def on_copy_clipboard_complete(self, subproc, result):
-        def _convert_stream_to_string(stream):
-            """Convert Gio.InputStream to string"""
-            bytes = bytearray(0)
-            buf = stream.read_bytes(1024, None).get_data()
-            while buf:
-                bytes += buf
-                buf = stream.read_bytes(1024, None).get_data()
-            stream.close()
-            content = bytes.decode("utf-8")
-            return content
-        try:
-            status = subproc.wait_check_finish(result)
-            if status:
-                clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-                clipboard.set_text(_convert_stream_to_string(subproc.get_stdout_pipe()), -1)
-        except Exception as e:
-            print("copying to clipboard failed : %s" % e.message)
+            print("An error occurred while copying the system information to clipboard")
+            print(e)
 
     def on_button_clicked(self, button, spinner):
 
